pub enum PvrtcCompression {
Pvrtc2BppRgb,
Pvrtc2BppRgba,
Pvrtc4BppRgb,
Pvrtc4BppRgba,
Etc2Rgb,
Etc2Rgba,
Etc2RgbA1,
EacR11,
EacRg11,
Unknown,
}Expand description
Compression formats for PVRTC containers
PowerVR containers can contain different compression formats beyond just PVRTC. This enum identifies the specific compression algorithm used within the PowerVR container.
Variants
Pvrtc2BppRgb
PVRTC 2 bits per pixel RGB
Pvrtc2BppRgba
PVRTC 2 bits per pixel RGBA
Pvrtc4BppRgb
PVRTC 4 bits per pixel RGB
Pvrtc4BppRgba
PVRTC 4 bits per pixel RGBA
Etc2Rgb
ETC2 RGB compression
Etc2Rgba
ETC2 RGBA compression
Etc2RgbA1
ETC2 RGB with 1-bit alpha
EacR11
EAC R11 (single channel)
EacRg11
EAC RG11 (dual channel)
Unknown
Other/Unknown format